==> zio-aws-cloudformation_2.12-5.19.8.3-sources.jar: zio/aws/cloudformation/model/StackInstanceDetailedStatus.scala <==
package zio.aws.cloudformation.model
import scala.jdk.CollectionConverters._
sealed trait StackInstanceDetailedStatus {
  def unwrap: software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus
}
object StackInstanceDetailedStatus {
  def wrap(
      value: software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus
  ): zio.aws.cloudformation.model.StackInstanceDetailedStatus = value match {
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.RUNNING =>
      val r = RUNNING
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SUCCEEDED =>
      val r = SUCCEEDED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.FAILED =>
      val r = FAILED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.CANCELLED =>
      val r = CANCELLED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.INOPERABLE =>
      val r = INOPERABLE
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.PENDING
  }
  case object RUNNING
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.RUNNING
  }
  case object SUCCEEDED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SUCCEEDED
  }
  case object FAILED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.FAILED
  }
  case object CANCELLED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.CANCELLED
  }
  case object INOPERABLE
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.INOPERABLE
  }
}

==> zio-aws-cloudformation_2.13-7.21.15.5-sources.jar: zio/aws/cloudformation/model/StackInstanceDetailedStatus.scala <==
package zio.aws.cloudformation.model
import scala.jdk.CollectionConverters._
sealed trait StackInstanceDetailedStatus {
  def unwrap: software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus
}
object StackInstanceDetailedStatus {
  def wrap(
      value: software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus
  ): zio.aws.cloudformation.model.StackInstanceDetailedStatus = value match {
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.PENDING =>
      val r = PENDING
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.RUNNING =>
      val r = RUNNING
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SUCCEEDED =>
      val r = SUCCEEDED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.FAILED =>
      val r = FAILED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.CANCELLED =>
      val r = CANCELLED
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.INOPERABLE =>
      val r = INOPERABLE
      r
    case software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SKIPPED_SUSPENDED_ACCOUNT =>
      val r = SKIPPED_SUSPENDED_ACCOUNT
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object PENDING
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.PENDING
  }
  case object RUNNING
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.RUNNING
  }
  case object SUCCEEDED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SUCCEEDED
  }
  case object FAILED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.FAILED
  }
  case object CANCELLED
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.CANCELLED
  }
  case object INOPERABLE
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.INOPERABLE
  }
  case object SKIPPED_SUSPENDED_ACCOUNT
      extends zio.aws.cloudformation.model.StackInstanceDetailedStatus {
    override def unwrap
        : software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus =
      software.amazon.awssdk.services.cloudformation.model.StackInstanceDetailedStatus.SKIPPED_SUSPENDED_ACCOUNT
  }
}
